@@ -1,10 +1,8 @@
-import base64
 import os
-import sys
-from traitlets import default
 
 import jinja2
 from nbconvert.exporters.html import HTMLExporter
+from traitlets import default
 
 from .utils import DEV_MODE
 
